import{R as n,e as d,J as l,r as a,j as e,H as u,i as p,a as f,b as c,c as m}from"../chunks/chunk-CQIL0Xd9.js";import{V as h,T as w,F as T,L as S,Z as y,A as g,W as x,n as E,f as P,g as j,H as v,h as R,M as A}from"../chunks/chunk-BPjIPZ-5.js";import{X as U,D}from"../chunks/chunk-BhBOHBDA.js";import"../chunks/chunk-D7HrI6pR.js";const z="_main_ct6c1_1",V={main:z};typeof window<"u"&&(window.React=n,window.ReactDOM=d,window.VUER=h,window.THREE=w,window.JSX=l,window.FIBER=T,window.XR=U,window.Drei=D,window.LEVA=S,window.ZUSTAND=y);function b(){return e.jsx(E,{bgChildren:[e.jsx(j,{_key:"grid"},"grid"),e.jsx(v,{},"default-light-stage"),e.jsx(R,{},"hands"),e.jsx(A,{fps:30,stream:!0},"motion-controllers")],children:e.jsx(P,{_key:"contrib-loader-mujoco",library:"@vuer-ai/mujoco-ts",version:"0.0.61",main:"dist/index.umd.js"})})}function H(){const s=typeof window>"u",[{message:C,mtype:M},t]=a.useState({message:null,mtype:null});a.useEffect(()=>{const o=console.error;return()=>{console.error=o}},[]),a.useEffect(()=>{const o=console.warn;return console.warn=r=>{setTimeout(()=>{t({message:r,mtype:"warning"}),console.log(r)},1)},()=>{console.warn=o}},[]);const i=a.useMemo(()=>({showError:o=>setTimeout(()=>t({message:o,mtype:"error"}),1),showSuccess:o=>setTimeout(()=>t({message:o,mtype:"success"}),1),showWarning:o=>setTimeout(()=>t({message:o,mtype:"warning"}),1),showInfo:o=>setTimeout(()=>t({message:o,mtype:"info"}),1),showModal:o=>{console.log(o)}}),[]);return e.jsxs(e.Fragment,{children:[e.jsx(u,{children:e.jsx("title",{children:"Vuer (Technical Preview)"})}),e.jsx("main",{className:V.main,children:e.jsx(g,{value:i,children:s?null:e.jsx(x,{children:e.jsx(b,{})})})})]})}const _=Object.freeze(Object.defineProperty({__proto__:null,default:H},Symbol.toStringTag,{value:"Module"})),F={onBeforeRenderEnv:{type:"computed",definedAtData:null,valueSerialized:{type:"js-serialized",value:null}},dataEnv:{type:"computed",definedAtData:null,valueSerialized:{type:"js-serialized",value:null}},hydrationCanBeAborted:{type:"standard",definedAtData:{filePathToShowToUser:"/renderer/+config.ts",fileExportPathToShowToUser:["default","hydrationCanBeAborted"]},valueSerialized:{type:"js-serialized",value:!0}},hooksTimeout:{type:"standard",definedAtData:{filePathToShowToUser:"/renderer/+config.ts",fileExportPathToShowToUser:["default","hooksTimeout"]},valueSerialized:{type:"js-serialized",value:{data:{error:3e4,warning:1e4}}}},onHydrationEnd:{type:"standard",definedAtData:{filePathToShowToUser:"/renderer/+onHydrationEnd.ts",fileExportPathToShowToUser:[]},valueSerialized:{type:"plus-file",exportValues:m}},onPageTransitionEnd:{type:"standard",definedAtData:{filePathToShowToUser:"/renderer/+onPageTransitionEnd.ts",fileExportPathToShowToUser:[]},valueSerialized:{type:"plus-file",exportValues:c}},onPageTransitionStart:{type:"standard",definedAtData:{filePathToShowToUser:"/renderer/+onPageTransitionStart.ts",fileExportPathToShowToUser:[]},valueSerialized:{type:"plus-file",exportValues:f}},onRenderClient:{type:"standard",definedAtData:{filePathToShowToUser:"/renderer/+onRenderClient.tsx",fileExportPathToShowToUser:[]},valueSerialized:{type:"plus-file",exportValues:p}},Page:{type:"standard",definedAtData:{filePathToShowToUser:"/pages/index/+Page.tsx",fileExportPathToShowToUser:[]},valueSerialized:{type:"plus-file",exportValues:_}}};export{F as configValuesSerialized};
//# sourceMappingURL=pages_index.BasHwMRM.js.map
